class ListObject(list):

    def __init__(self, obj):
        super().__init__()
        self.obj = obj

    def append(self, obj_t):
        if isinstance(obj_t, self.obj):
            super().append(obj_t)
        else:
            raise Exception(
                "Given {} but required {}.".format(type(obj_t), type(self.obj)))

    def insert(self, index: int, obj_t):
        if isinstance(obj_t, self.obj):
            super().insert(index, obj_t)
        else:
            raise Exception(
                "Given {} but required {}.".format(type(obj_t), type(self.obj)))



class CamelCase:
    def __init__(self, function):
        self.function = function
        self.obj = None

    def __call__(self, *args, **kwargs):
        try:
            self.obj = self.function(*args, **kwargs)
            func_dict = self.obj.__dict__
            class_var_value = {var: func_dict[var] for var in func_dict}
            for _var in class_var_value:
                self.obj.__setattr__(self.camel_type(_var), class_var_value[_var])
                self.obj.__delattr__(_var)

            return self.obj

        except Exception as e:
            print("Error while converting to camel case : {}".format(e))
            raise e

    def __instancecheck__(self, dec_class):
        return self.obj

    def camel_type(self, snake_str):
        try:
            return "".join(x.title() for x in snake_str.split("_"))
        except Exception as e:
            print("Error While converting to camel case : {}".format(e))
            raise e



import json


def json_to_obj(json_data, class_type):
    ct = class_type()
    j = json.loads(json_data)
    for i in dir(ct):
        if not i.startswith("__"):
            setattr(ct, i, j[i] if i in j else None)
    return ct


def obj_to_json(obj):
    json_obj = json.dumps(obj, default=lambda x: x.__dict__)
    return json_obj



from setuptools import setup

with open("README.md", "r") as readme:
    description = readme.read()

with open("LICENSE", "r") as readme:
    license_x = readme.read()

license_x_y = " : ".join(x for x in license_x.split("\n")[:3] if x)

description = "{} \n\n {}".format(description, license_x_y)

setup(
    name='jangli',
    version='1.1.3',
    packages=['jangli'],
    url='https://github.com/AbhimanyuHK/Json_Object_Conv',
    license=license_x_y,
    author='Abimanyu H K',
    author_email='manyu1994@hotmail.com',
    description='Data Object Mapping',
    long_description=description,
    long_description_content_type="text/markdown"
)
